Calculate the demand share equations of a AI or QUAI demand system, including demographic variable, using point estimates (e.g., mean, median, percentiles).
muaidsCalculate(
muPrices = numeric(),
muBudget = numeric(),
muDemographics = numeric(),
Params = matrix(),
quaids = FALSE,
m = numeric(),
t = numeric(),
dems = FALSE
)A matrix of estimated shares with (1xm) dimensions where n is the number of observations and m the number of shares.
A matrix of logged muPrices with (1xm) dimensions where n is the number of observations and m the number of shares.
A matrix of logged total expenditure/muBudget with (1x1) dimensions where n is the number of observations.
A matrix of demographic variables with (1xt) dimensions where n is the number of observations and t the number of demographic variables.
A vector containing the parameters alpha, beta, gamma, and theta and lambda if elected.
Logical. Should quadratic form be used instead?
Number of shares.
Number of demographic variables.
Bolean. Should demographic variables be included?